#!perl -T
use 5.006;
use strict;
use warnings FATAL => 'all';
use Test::More;

plan tests => 1;

BEGIN {
    use_ok( 'Mojolicious::Command::scaffold' ) || print "Bail out!\n";
}

diag( "Testing Mojolicious::Command::scaffold $Mojolicious::Command::scaffold::VERSION, Perl $], $^X" );
